@@ -254,4 +254,14 @@ class JiraIssue(Document):
 
 class SkippedRepo(Document):
     repo_name = StringField(max_length=120, primary_key=True, required=True)
-    error = StringField(max_length=10000)
\ No newline at end of file
+    error = StringField(max_length=10000)
+
+
+class UserContribution(Document):
+    organization = StringField()
+    repository = StringField()
+    user = StringField()
+    file = StringField()
+    line_id = StringField()
+    line_number = IntField()
+    timestamp = DateTimeField()
